aboutsummaryrefslogtreecommitdiffstats
path: root/src/ui/function/VersionCheckThread.h
diff options
context:
space:
mode:
authorSaturn&Eric <[email protected]>2021-12-05 08:14:53 +0000
committerGitHub <[email protected]>2021-12-05 08:14:53 +0000
commitab7e3bac8b5f1d1fdd8367bdb1a185be36b281c2 (patch)
tree234892f5ae225d67b24619209cf57636ec9d9b2d /src/ui/function/VersionCheckThread.h
parentMerge branch 'main' of github.com:saturneric/GpgFrontend (diff)
parentRemove rapidjson and Improve update ploicy. (diff)
downloadGpgFrontend-ab7e3bac8b5f1d1fdd8367bdb1a185be36b281c2.tar.gz
GpgFrontend-ab7e3bac8b5f1d1fdd8367bdb1a185be36b281c2.zip
Merge pull request #25 from saturneric/develop
Merge version 2.0.1 beta
Diffstat (limited to '')
-rw-r--r--src/ui/function/VersionCheckThread.h (renamed from include/ui/help/VersionCheckThread.h)34
1 files changed, 17 insertions, 17 deletions
diff --git a/include/ui/help/VersionCheckThread.h b/src/ui/function/VersionCheckThread.h
index 7ee90077..181ee947 100644
--- a/include/ui/help/VersionCheckThread.h
+++ b/src/ui/function/VersionCheckThread.h
@@ -1,7 +1,7 @@
/**
* This file is part of GPGFrontend.
*
* GPGFrontend is free software: you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation, either version 3 of the License, or
* (at your option) any later version.
@@ -25,28 +25,28 @@
#ifndef GPGFRONTEND_VERSIONCHECKTHREAD_H
#define GPGFRONTEND_VERSIONCHECKTHREAD_H
-#include "GpgFrontend.h"
+#include "ui/GpgFrontendUI.h"
-class VersionCheckThread : public QThread {
-Q_OBJECT
-
-public:
-
- VersionCheckThread(QNetworkReply *networkReply);
+namespace GpgFrontend::UI {
-signals:
-
- void upgradeVersion(const QString &currentVersion, const QString &latestVersion);
+class VersionCheckThread : public QThread {
+ Q_OBJECT
-protected:
+ public:
+ explicit VersionCheckThread(QNetworkReply* networkReply);
- void run() override;
+ signals:
-private:
+ void upgradeVersion(const QString& currentVersion,
+ const QString& latestVersion);
- QNetworkReply* mNetworkReply;
+ protected:
+ void run() override;
+ private:
+ QNetworkReply* mNetworkReply;
};
+} // namespace GpgFrontend::UI
-#endif //GPGFRONTEND_VERSIONCHECKTHREAD_H
+#endif // GPGFRONTEND_VERSIONCHECKTHREAD_H
@@ -1,7 +1,7 @@
/**
- * This file is part of GPGFrontend.
+ * This file is part of GpgFrontend.
*
@@ -1,7 +1,7 @@
*
- * GPGFrontend is free software: you can redistribute it and/or modify
+ * GpgFrontend is free software: you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation, either version 3 of the License, or